@@ -10,14 +10,16 @@ from ape_etherscan.client import ClientFactory, get_etherscan_uri
 
 class Etherscan(ExplorerAPI):
     def get_address_url(self, address: str) -> str:
-        return f"{get_etherscan_uri(self.network.name)}/address/{address}"
+        etherscan_uri = get_etherscan_uri(self.network.ecosystem.name, self.network.name)
+        return f"{etherscan_uri}/address/{address}"
 
     def get_transaction_url(self, transaction_hash: str) -> str:
-        return f"{get_etherscan_uri(self.network.name)}/tx/{transaction_hash}"
+        etherscan_uri = get_etherscan_uri(self.network.ecosystem.name, self.network.name)
+        return f"{etherscan_uri}/tx/{transaction_hash}"
 
     @property
     def _client_factory(self) -> ClientFactory:
-        return ClientFactory(self.network.name)
+        return ClientFactory(self.network.ecosystem.name, self.network.name)
 
     def get_contract_type(self, address: str) -> Optional[ContractType]:
         client = self._client_factory.get_contract_client(address)
